Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Amazon GuardDuty.

Actions, resources, and condition keys for Amazon GuardDuty - Service Authorization Reference

# Actions, resources, and condition keys for Amazon GuardDuty

Amazon GuardDuty (service prefix: `guardduty` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

###### Topics

- Actions defined by Amazon GuardDuty
- Resource types defined by Amazon GuardDuty
- Condition keys for Amazon GuardDuty

## Actions defined by Amazon GuardDuty

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column of the Actions table indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") to which the policy applies in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. If the action has one or more required resources, the caller must have permission to use the action with those resources. Required resources are indicated in the table with an asterisk (*). If you limit resource access with the `Resource` element in an IAM policy, you must include an ARN or pattern for each required resource type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one of the optional resource types.

The Condition keys column of the Actions table includes keys that you can specify in a policy statement's `Condition` element. For more information on the condition keys that are associated with resources for the service, see the Condition keys column of the Resource types table.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
AcceptAdministratorInvitation | Grants permission to accept invitations to become a GuardDuty member account | Write |  |  |
AcceptInvitation | Grants permission to accept invitations to become a GuardDuty member account | Write |  |  |
ArchiveFindings | Grants permission to archive GuardDuty findings | Write |  |  |
CreateDetector | Grants permission to create a detector | Write |  | aws:RequestTag/${TagKey} aws:TagKeys |
CreateFilter | Grants permission to create GuardDuty filters. A filters defines finding attributes and conditions used to filter findings | Write | filter* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateIPSet | Grants permission to create an IPSet | Write |  | aws:RequestTag/${TagKey} aws:TagKeys | iam:DeleteRolePolicy iam:PutRolePolicy
CreateMembers | Grants permission to create GuardDuty member accounts, where the account used to create a member becomes the GuardDuty administrator account | Write |  |  |
CreatePublishingDestination | Grants permission to create a publishing destination | Write |  |  | s3:GetObject s3:ListBucket
CreateSampleFindings | Grants permission to create sample findings | Write |  |  |
CreateThreatIntelSet | Grants permission to create GuardDuty ThreatIntelSets, where a ThreatIntelSet consists of known malicious IP addresses used by GuardDuty to generate findings | Write |  | aws:RequestTag/${TagKey} aws:TagKeys |
DeclineInvitations | Grants permission to decline invitations to become a GuardDuty member account | Write |  |  |
DeleteDetector | Grants permission to delete GuardDuty detectors | Write | detector* |  |
DeleteFilter | Grants permission to delete GuardDuty filters | Write | filter* |  |
DeleteIPSet | Grants permission to delete GuardDuty IPSets | Write | ipset* |  |
DeleteInvitations | Grants permission to delete invitations to become a GuardDuty member account | Write |  |  |
DeleteMembers | Grants permission to delete GuardDuty member accounts | Write |  |  |
DeletePublishingDestination | Grants permission to delete a publishing destination | Write | publishingDestination* |  |
DeleteThreatIntelSet | Grants permission to delete GuardDuty ThreatIntelSets | Write | threatintelset* |  |
DescribeMalwareScans | Grants permission to retrieve details about malware scans | Read |  |  |
DescribeOrganizationConfiguration | Grants permission to retrieve details about the delegated administrator associated with a GuardDuty detector | Read |  |  |
DescribePublishingDestination | Grants permission to retrieve details about a publishing destination | Read | publishingDestination* |  |
DisableOrganizationAdminAccount | Grants permission to disable the organization delegated administrator for GuardDuty | Write |  |  |
DisassociateFromAdministratorAccount | Grants permission to disassociate a GuardDuty member account from its GuardDuty administrator account | Write |  |  |
DisassociateFromMasterAccount | Grants permission to disassociate a GuardDuty member account from its GuardDuty administrator account | Write |  |  |
DisassociateMembers | Grants permission to disassociate GuardDuty member accounts from their administrator GuardDuty account | Write |  |  |
EnableOrganizationAdminAccount | Grants permission to enable an organization delegated administrator for GuardDuty | Write |  |  |
GetAdministratorAccount | Grants permission to retrieve details of the GuardDuty administrator account associated with a member account | Read |  |  |
GetCoverageStatistics | Grants permission to list Amazon GuardDuty coverage statistics for the specified GuardDuty account in a Region | Read | detector* |  |
GetDetector | Grants permission to retrieve GuardDuty detectors | Read | detector* |  |
GetFilter | Grants permission to retrieve GuardDuty filters | Read | filter* |  |
GetFindings | Grants permission to retrieve GuardDuty findings | Read |  |  |
GetFindingsStatistics | Grants permission to retrieve a list of GuardDuty finding statistics | Read |  |  |
GetIPSet | Grants permission to retrieve GuardDuty IPSets | Read | ipset* |  |
GetInvitationsCount | Grants permission to retrieve the count of all GuardDuty invitations sent to a specified account, which does not include the accepted invitation | Read |  |  |
GetMalwareScanSettings | Grants permission to retrieve the malware scan settings | Read |  |  |
GetMasterAccount | Grants permission to retrieve details of the GuardDuty administrator account associated with a member account | Read |  |  |
GetMemberDetectors | Grants permission to describe which data sources are enabled for member accounts detectors | Read |  |  |
GetMembers | Grants permission to retrieve the member accounts associated with an administrator account | Read |  |  |
GetRemainingFreeTrialDays | Grants permission to provide the number of days left for each data source used in the free trial period | Read |  |  |
GetThreatIntelSet | Grants permission to retrieve GuardDuty ThreatIntelSets | Read | threatintelset* |  |
GetUsageStatistics | Grants permission to list Amazon GuardDuty usage statistics over the last 30 days for the specified detector ID | Read |  |  |
InviteMembers | Grants permission to invite other AWS accounts to enable GuardDuty and become GuardDuty member accounts | Write |  |  |
ListCoverage | Grants permission to list all the resource details for a given account in a Region | List | detector* |  |
ListDetectors | Grants permission to retrieve a list of GuardDuty detectors | List |  |  |
ListFilters | Grants permission to retrieve a list of GuardDuty filters | List |  |  |
ListFindings | Grants permission to retrieve a list of GuardDuty findings | List |  |  |
ListIPSets | Grants permission to retrieve a list of GuardDuty IPSets | List |  |  |
ListInvitations | Grants permission to retrieve a list of all of the GuardDuty membership invitations that were sent to an AWS account | List |  |  |
ListMembers | Grants permission to retrieve a list of GuardDuty member accounts associated with an administrator account | List |  |  |
ListOrganizationAdminAccounts | Grants permission to list details about the organization delegated administrator for GuardDuty | List |  |  |
ListPublishingDestinations | Grants permission to retrieve a list of publishing destinations | List |  |  |
ListTagsForResource | Grants permission to retrieve a list of tags associated with a GuardDuty resource | Read | detector |  |
filter |  |
ipset |  |
threatintelset |  |
ListThreatIntelSets | Grants permission to retrieve a list of GuardDuty ThreatIntelSets | List |  |  |
SendSecurityTelemetry | Grants permission to send security telemetry for a specific GuardDuty account in a Region | Write |  |  |
StartMalwareScan | Grants permission to initiate a new malware scan | Write |  |  |
StartMonitoringMembers | Grants permission to a GuardDuty administrator account to monitor findings from GuardDuty member accounts | Write |  |  |
StopMonitoringMembers | Grants permission to disable monitoring findings from member accounts | Write |  |  |
TagResource | Grants permission to add tags to a GuardDuty resource | Tagging | detector |  |
filter |  |
ipset |  |
threatintelset |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
UnarchiveFindings | Grants permission to unarchive GuardDuty findings | Write |  |  |
UntagResource | Grants permission to remove tags from a GuardDuty resource | Tagging | detector |  |
filter |  |
ipset |  |
threatintelset |  |
| aws:TagKeys |
UpdateDetector | Grants permission to update GuardDuty detectors | Write | detector* |  |
UpdateFilter | Grants permission to updates GuardDuty filters | Write | filter* |  |
UpdateFindingsFeedback | Grants permission to update findings feedback to mark GuardDuty findings as useful or not useful | Write |  |  |
UpdateIPSet | Grants permission to update GuardDuty IPSets | Write | ipset* |  | iam:DeleteRolePolicy iam:PutRolePolicy
UpdateMalwareScanSettings | Grants permission to update the malware scan settings | Write |  |  |
UpdateMemberDetectors | Grants permission to update which data sources are enabled for member accounts detectors | Write |  |  |
UpdateOrganizationConfiguration | Grants permission to update the delegated administrator configuration associated with a GuardDuty detector | Write |  |  |
UpdatePublishingDestination | Grants permission to update a publishing destination | Write | publishingDestination* |  | s3:GetObject s3:ListBucket
UpdateThreatIntelSet | Grants permission to updates the GuardDuty ThreatIntelSets | Write | threatintelset* |  | iam:DeleteRolePolicy iam:PutRolePolicy

## Resource types defined by Amazon GuardDuty

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the Resource types table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
detector | `arn:$ { Partition}:guardduty:$ { Region}:$ { Account}:detector/$ { DetectorId}` | aws:ResourceTag/${TagKey}
filter | `arn:$ { Partition}:guardduty:$ { Region}:$ { Account}:detector/$ { DetectorId}/filter/$ { FilterName}` | aws:ResourceTag/${TagKey}
ipset | `arn:$ { Partition}:guardduty:$ { Region}:$ { Account}:detector/$ { DetectorId}/ipset/$ { IPSetId}` | aws:ResourceTag/${TagKey}
threatintelset | `arn:$ { Partition}:guardduty:$ { Region}:$ { Account}:detector/$ { DetectorId}/threatintelset/$ { ThreatIntelSetId}` | aws:ResourceTag/${TagKey}
publishingDestination | `arn:$ { Partition}:guardduty:$ { Region}:$ { Account}:detector/$ { DetectorId}/publishingDestination/$ { PublishingDestinationId}` |

## Condition keys for Amazon GuardDuty

Amazon GuardDuty defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see Condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters access by tag key-value pairs in the request | String
aws:ResourceTag/${TagKey} | Filters access by tag key-value pairs attached to the resource | String
aws:TagKeys | Filters access by tag keys in the request | ArrayOfString

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.